@@ -90,7 +90,7 @@ puppet-agent(8) -- #{summary}
 
 SYNOPSIS
 --------
-Retrieves the client configuration from the puppet master and applies it to
+Retrieves the client configuration from the Puppet master and applies it to
 the local host.
 
 This service may be run as a daemon, run periodically using cron (or something
@@ -164,13 +164,15 @@ when signing certificates).
 only resources not tagged with the specified tags will be applied.
 Values must be comma-separated.
 
+
 OPTIONS
 -------
 
 Note that any Puppet setting that's valid in the configuration file is also a
 valid long argument. For example, 'server' is a valid setting, so you can
-specify '--server <servername>' as an argument. Boolean settings translate into
-'--setting' and '--no-setting' pairs.
+specify '--server <servername>' as an argument. Boolean settings accept a '--no-' 
+prefix to turn off a behavior, translating into '--setting' and '--no-setting' 
+pairs, such as `--daemonize` and `--no-daemonize`.
 
 See the configuration file documentation at
 https://puppet.com/docs/puppet/latest/configuration.html for the
@@ -237,15 +239,14 @@ generated by running puppet agent with '--genconfig'.
 * --enable:
   Enable working on the local system. This removes any lock file,
   causing 'puppet agent' to start managing the local system again
-  (although it will continue to use its normal scheduling, so it might
-  not start for another half hour).
+  However, it continues to use its normal scheduling, so it might
+  not start for another half hour.
 
   'puppet agent' exits after executing this.
   
 *  --evaltrace:
   Logs each resource as it is being evaluated. This allows you to interactively see exactly what is being done. (This is a Puppet setting, and can go in puppet.conf. Note the special 'no-' prefix for boolean settings on the command line.)
 
-
 * --fingerprint:
   Display the current certificate or certificate signing request
   fingerprint and then exit. Use the '--digest' option to change the
@@ -278,7 +279,7 @@ generated by running puppet agent with '--genconfig'.
 
 * --noop:
   Use 'noop' mode where the daemon runs in a no-op or dry-run mode. This
-  is useful for seeing what changes Puppet will make without actually
+  is useful for seeing what changes Puppet would make without actually
   executing the changes.
   (This is a Puppet setting, and can go in puppet.conf. Note the special 'no-'
   prefix for boolean settings on the command line.)
@@ -302,8 +303,6 @@ generated by running puppet agent with '--genconfig'.
 * --trace
   Prints stack traces on some errors. (This is a Puppet setting, and can go in puppet.conf. Note the special 'no-' prefix for boolean settings on the command line.)
 
-
-
 * --verbose:
   Turn on verbose reporting.
 
@@ -317,8 +316,7 @@ generated by running puppet agent with '--genconfig'.
   it to sign a certificate request. This is useful for the initial setup
   of a puppet client. You can turn off waiting for certificates by
   specifying a time of 0.
-  (This is a Puppet setting, and can go in puppet.conf. Note the special 'no-'
-  prefix for boolean settings on the command line.)
+  (This is a Puppet setting, and can go in puppet.conf.)
 
 
 EXAMPLE
