@@ -194,7 +194,7 @@ you can specify '--server <servername>' as an argument.
 
 * --resource:
   Displays a resource state as Puppet code, roughly equivalent to
-  `puppet resource`.  Can be filterd by title. Requires --target be specified.
+  `puppet resource`.  Can be filtered by title. Requires --target be specified.
 
 * --target:
   Target a specific device/certificate in the device.conf. Doing so will perform a
@@ -259,7 +259,7 @@ Licensed under the Apache 2.0 License
         end
       end
       devices.collect do |devicename,device|
-        pool = Puppet::Network::HTTP::Pool.new(Puppet[:http_keepalive_timeout])
+        pool = Puppet.runtime['http'].pool
         Puppet.override(:http_pool => pool) do
           # TODO when we drop support for ruby < 2.5 we can remove the extra block here
           begin
