@@ -2,9 +2,9 @@ class Puppet::HTTP::Service::Ca < Puppet::HTTP::Service
   HEADERS = { 'Accept' => 'text/plain' }.freeze
   API = '/puppet-ca/v1'.freeze
 
-  def initialize(client, server, port)
+  def initialize(client, session, server, port)
     url = build_url(API, server || Puppet[:ca_server], port || Puppet[:ca_port])
-    super(client, url)
+    super(client, session, url)
   end
 
   def get_certificate(name, ssl_context: nil)
@@ -14,9 +14,9 @@ class Puppet::HTTP::Service::Ca < Puppet::HTTP::Service
       ssl_context: ssl_context
     )
 
-    return response.body.to_s if response.success?
+    process_response(response)
 
-    raise Puppet::HTTP::ResponseError.new(response)
+    response.body.to_s
   end
 
   def get_certificate_revocation_list(if_modified_since: nil, ssl_context: nil)
@@ -29,9 +29,9 @@ class Puppet::HTTP::Service::Ca < Puppet::HTTP::Service
       ssl_context: ssl_context
     )
 
-    return response.body.to_s if response.success?
+    process_response(response)
 
-    raise Puppet::HTTP::ResponseError.new(response)
+    response.body.to_s
   end
 
   def put_certificate_request(name, csr, ssl_context: nil)
@@ -43,8 +43,8 @@ class Puppet::HTTP::Service::Ca < Puppet::HTTP::Service
       ssl_context: ssl_context
     )
 
-    return response.body.to_s if response.success?
+    process_response(response)
 
-    raise Puppet::HTTP::ResponseError.new(response)
+    response.body.to_s
   end
 end
