@@ -140,10 +140,12 @@ Puppet::Type.type(:package).provide :pkgdmg, :parent => Puppet::Provider::Packag
   end
 
   def install
-    unless source = @resource[:source]
+    source = @resource[:source]
+    unless source
       raise Puppet::Error.new(_("Mac OS X PKG DMGs must specify a package source."))
     end
-    unless name = @resource[:name]
+    name = @resource[:name]
+    unless name
       raise Puppet::Error.new(_("Mac OS X PKG DMGs must specify a package name."))
     end
     self.class.installpkgdmg(source,name)
